@@ -45,6 +45,10 @@ try:
 except:
     pass
 
+
+if 'CS_ARCH_ARM64' not in globals():
+    CS_ARCH_ARM64 = CS_ARCH_AARCH64
+
 def byte_regexp(bitmask, bitvalues):
     r = b'['
     for value in range(256):
